==> 0.0.1%2B1.tar.gz: lib/models/IR5BtnProperties.dart <==
import 'package:json_annotation/json_annotation.dart';

part 'IR5BtnProperties.g.dart';

@JsonSerializable()
class IR5BtnProperties {
  IR5BtnProperties({
    required this.Color,
    required this.FontColor,
    required this.FontSize,
    required this.Font,
    required this.Bmp,
    required this.BevelWidth,
    required this.Properties,
    required this.BtnStyle,
    required this.TextStyle,
    required this.BtnSize,
  });

  factory IR5BtnProperties.fromJson(Map<String, dynamic>? json) => _$IR5BtnPropertiesFromJson(json ?? {});
  Map<String, dynamic> toJson() => _$IR5BtnPropertiesToJson(this);

  /** Color as rgb(r,g,b) */
  @JsonKey(defaultValue: '')
  final String Color;

  /** Color IntValue or RGB(r,g,b) */
  @JsonKey(defaultValue: '')
  final String FontColor;

  /** Btn Text Font Size */
  @JsonKey(defaultValue: 0)
  final num FontSize;

  /** Btn Text Font */
  @JsonKey(defaultValue: '')
  final String Font;

  /** Image Num */
  @JsonKey(defaultValue: 0)
  final num Bmp;

  /** Btn Bevel Width */
  @JsonKey(defaultValue: 0)
  final num BevelWidth;

  /** Button Flags
   *   Bit 00 : ShadowText
   *   Bit 01 : FlatText
   *   Bit 03 : StyleSpeedBtn
   *   Bit 04 : StyleBtn
   *   Bit 05 : LedTopStyleBtn
   *   Bit 06 : LedRightStyleBtn
   *   Bit 07 : LedLeftStyleBtn
   *   Bit 08 : LedBottomStyleBtn
   *   Bit 09 : Bevel
   *   Bit 10 : Btn
   *   Bit 11 : Edged
   *   Bit 12 : Encarta
   *   Bit 13 : Rounded
   *   Bit 14 : Label
   *   Bit 16 : Flat
   *   Bit 17 : TouchSquare
   *   Bit 18 : TouchRound
   *   Bit 21 : GotoSearchList
   *   Bit 50 : 1x1
   *   Bit 51 : 2x1
   *   Bit 52 : 1x2
   *   Bit 53 : 2x2
   */
  @JsonKey(defaultValue: 0)
  final num Properties;

  /** BtnStyle:[StyleSpeedBtn,StyleBtn,LedTopStyleBtn,LedRightStyleBtn,LedLeftStyleBtn,LedBottomStyleBtn,Bevel,Btn,Edged,Encarta,Rounded,Label,Flat,TouchSquare,TouchRound] */
  @JsonKey(defaultValue: '')
  final String BtnStyle;

  /** TextStyle:[ShadowText,FlatText] */
  @JsonKey(defaultValue: '')
  final String TextStyle;

  /** BtnSize:[1x1,2x1,1x2,2x2] */
  @JsonKey(defaultValue: '')
  final String BtnSize;
}

==> 0.0.2%2B1.tar.gz: lib/models/IR5BtnProperties.dart <==
import 'package:json_annotation/json_annotation.dart';

part 'IR5BtnProperties.g.dart';

@JsonSerializable()
class IR5BtnProperties {
  IR5BtnProperties({
    required this.Color,
    required this.FontColor,
    required this.FontSize,
    required this.Font,
    required this.Bmp,
    required this.BevelWidth,
    required this.Properties,
    required this.BtnStyle,
    required this.TextStyle,
    required this.BtnSize,
  });

  factory IR5BtnProperties.fromJson(Map<String, dynamic>? json) =>
      _$IR5BtnPropertiesFromJson(json ?? {});
  Map<String, dynamic> toJson() => _$IR5BtnPropertiesToJson(this);

  /** Color as rgb(r,g,b) */
  @JsonKey(defaultValue: '')
  final String Color;

  /** Color IntValue or RGB(r,g,b) */
  @JsonKey(defaultValue: '')
  final String FontColor;

  /** Btn Text Font Size */
  @JsonKey(defaultValue: 0)
  final num FontSize;

  /** Btn Text Font */
  @JsonKey(defaultValue: '')
  final String Font;

  /** Image Num */
  @JsonKey(defaultValue: 0)
  final num Bmp;

  /** Btn Bevel Width */
  @JsonKey(defaultValue: 0)
  final num BevelWidth;

  /** Button Flags
   *   Bit 00 : ShadowText
   *   Bit 01 : FlatText
   *   Bit 03 : StyleSpeedBtn
   *   Bit 04 : StyleBtn
   *   Bit 05 : LedTopStyleBtn
   *   Bit 06 : LedRightStyleBtn
   *   Bit 07 : LedLeftStyleBtn
   *   Bit 08 : LedBottomStyleBtn
   *   Bit 09 : Bevel
   *   Bit 10 : Btn
   *   Bit 11 : Edged
   *   Bit 12 : Encarta
   *   Bit 13 : Rounded
   *   Bit 14 : Label
   *   Bit 16 : Flat
   *   Bit 17 : TouchSquare
   *   Bit 18 : TouchRound
   *   Bit 21 : GotoSearchList
   *   Bit 50 : 1x1
   *   Bit 51 : 2x1
   *   Bit 52 : 1x2
   *   Bit 53 : 2x2
   */
  @JsonKey(defaultValue: 0)
  final num Properties;

  /** BtnStyle:[StyleSpeedBtn,StyleBtn,LedTopStyleBtn,LedRightStyleBtn,LedLeftStyleBtn,LedBottomStyleBtn,Bevel,Btn,Edged,Encarta,Rounded,Label,Flat,TouchSquare,TouchRound] */
  @JsonKey(defaultValue: '')
  final String BtnStyle;

  /** TextStyle:[ShadowText,FlatText] */
  @JsonKey(defaultValue: '')
  final String TextStyle;

  /** BtnSize:[1x1,2x1,1x2,2x2] */
  @JsonKey(defaultValue: '')
  final String BtnSize;
}
